@@ -13,12 +13,14 @@ from .entities import (
     WritableViewInstance,
 )
 from .schemas import get_parent_and_children_nodes, get_schema_properties
+from .utils import include_edges
 
 __all__ = [
     "AggregatedViewInstance",
     "RootModel",
     "EdgeContainer",
     "InstanceId",
+    "include_edges",
     "TAggregatedViewInstance",
     "TViewInstance",
     "TWritableViewInstance",
